==> wpewebkit_2.28.1.orig.tar.xz: wpewebkit-2.28.1/Source/WebCore/svg/properties/SVGAnimationDiscreteFunctionImpl.h <==
/*
 * Copyright (C) 2019 Apple Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "SVGAnimationDiscreteFunction.h"
#include "SVGPropertyTraits.h"

namespace WebCore {

class SVGAnimationBooleanFunction : public SVGAnimationDiscreteFunction<bool> {
public:
    using Base = SVGAnimationDiscreteFunction<bool>;
    using Base::Base;

    void setFromAndToValues(SVGElement*, const String& from, const String& to) override
    {
        m_from = SVGPropertyTraits<bool>::fromString(from);
        m_to = SVGPropertyTraits<bool>::fromString(to);
    }
};

template<typename EnumType>
class SVGAnimationEnumerationFunction : public SVGAnimationDiscreteFunction<EnumType> {
    using Base = SVGAnimationDiscreteFunction<EnumType>;
    using Base::m_from;
    using Base::m_to;

public:
    using Base::Base;

    void setFromAndToValues(SVGElement*, const String& from, const String& to) override
    {
        m_from = SVGPropertyTraits<EnumType>::fromString(from);
        m_to = SVGPropertyTraits<EnumType>::fromString(to);
    }
};

class SVGAnimationOrientTypeFunction : public SVGAnimationDiscreteFunction<SVGMarkerOrientType> {
public:
    using Base = SVGAnimationDiscreteFunction<SVGMarkerOrientType>;
    using Base::Base;

    void setFromAndToValues(SVGElement*, const String&, const String&) override
    {
        // Values will be set by SVGAnimatedAngleOrientAnimator.
        ASSERT_NOT_REACHED();
    }

private:
    friend class SVGAnimatedAngleOrientAnimator;
};

class SVGAnimationPreserveAspectRatioFunction : public SVGAnimationDiscreteFunction<SVGPreserveAspectRatioValue> {
public:
    using Base = SVGAnimationDiscreteFunction<SVGPreserveAspectRatioValue>;
    using Base::Base;
    
    void setFromAndToValues(SVGElement*, const String& from, const String& to) override
    {
        m_from = SVGPreserveAspectRatioValue(from);
        m_to = SVGPreserveAspectRatioValue(to);
    }
};

class SVGAnimationStringFunction : public SVGAnimationDiscreteFunction<String> {
public:
    using Base = SVGAnimationDiscreteFunction<String>;
    using Base::Base;
    
    void setFromAndToValues(SVGElement*, const String& from, const String& to) override
    {
        m_from = from;
        m_to = to;
    }
};

}

==> wpewebkit_2.48.3.orig.tar.xz: wpewebkit-2.48.3/Source/WebCore/svg/properties/SVGAnimationDiscreteFunctionImpl.h <==
/*
 * Copyright (C) 2019-2021 Apple Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "SVGAnimationDiscreteFunction.h"
#include "SVGPropertyTraits.h"

namespace WebCore {

class SVGAnimationBooleanFunction : public SVGAnimationDiscreteFunction<bool> {
public:
    using Base = SVGAnimationDiscreteFunction<bool>;
    using Base::Base;

    void setFromAndToValues(SVGElement&, const String& from, const String& to) override
    {
        m_from = SVGPropertyTraits<bool>::fromString(from);
        m_to = SVGPropertyTraits<bool>::fromString(to);
    }
};

template<typename EnumType>
class SVGAnimationEnumerationFunction : public SVGAnimationDiscreteFunction<EnumType> {
    using Base = SVGAnimationDiscreteFunction<EnumType>;
    using Base::m_from;
    using Base::m_to;

public:
    using Base::Base;

    void setFromAndToValues(SVGElement&, const String& from, const String& to) override
    {
        m_from = SVGPropertyTraits<EnumType>::fromString(from);
        m_to = SVGPropertyTraits<EnumType>::fromString(to);
    }
};

class SVGAnimationOrientTypeFunction : public SVGAnimationDiscreteFunction<SVGMarkerOrientType> {
public:
    using Base = SVGAnimationDiscreteFunction<SVGMarkerOrientType>;
    using Base::Base;

    void setFromAndToValues(SVGElement&, const String&, const String&) override
    {
        // Values will be set by SVGAnimatedAngleOrientAnimator.
        ASSERT_NOT_REACHED();
    }

private:
    friend class SVGAnimatedAngleOrientAnimator;
};

class SVGAnimationPreserveAspectRatioFunction : public SVGAnimationDiscreteFunction<SVGPreserveAspectRatioValue> {
public:
    using Base = SVGAnimationDiscreteFunction<SVGPreserveAspectRatioValue>;
    using Base::Base;
    
    void setFromAndToValues(SVGElement&, const String& from, const String& to) override
    {
        m_from = SVGPreserveAspectRatioValue(from);
        m_to = SVGPreserveAspectRatioValue(to);
    }
};

class SVGAnimationStringFunction : public SVGAnimationDiscreteFunction<String> {
public:
    using Base = SVGAnimationDiscreteFunction<String>;
    using Base::Base;
    
    void setFromAndToValues(SVGElement&, const String& from, const String& to) override
    {
        m_from = from;
        m_to = to;
    }
};

} // namespace WebCore
